Construct tables for rich display in IPython that will also render in LaTeX.

For usage details, see `the example notebook
<http://nbviewer.ipython.org/github/takluyver/ipytables/blob/master/docs/IPyTables.ipynb>`_ 
and its `rendered LaTeX output <https://github.com/takluyver/ipytables/raw/master/docs/IPyTables.pdf>`_.
